*     *****************************************************************
*     ***************************************************************** 
* 		File-Name:      combined DelPool_volIII_march2017.do      	                 
*   	Date:           20 March 2017                                 
*     	Author:         LH	                                          
*     	Purpose:        Create delegation and pooling variables by decision area                  
*    	Input File:     None                                            
*     	Output File:    DP_volIII_march17.dta			                         
*     	Data Output:    None                                            
*     	Previous file:  None                                            
*     	Machine:        	                                      
*     ****************************************************************  
*     ****************************************************************  

clear
*use "MASTER_march2017_FINAL.dta"

set more off
drop if missing(ioname) ///many missing values dropped
**save into new name

*ALL SCORES ARE RESCALED ONTO A 0-1 SCALE


****************************************************************************((((
**COMPONENT 1 of delegation: DELEGATION TO DISPUTE SETTLEMENT
///Replace all 98 and 99 in DS components with 0
****************************************************************************
*Note: all dispute settlement components are already rescored onto a 0-1 scale (instead of 0-2).


foreach x of varlist coverage* thirdparty* tribunal* binding* remedy* nonstate* preliminary*{
replace `x' = 0 if `x'==98
replace `x' = 0 if `x'==99
}

egen DS_sum1= rsum (coverage1 thirdparty1 tribunal1 binding1 remedy1 nonstate1 preliminary1)
egen DS_sum2= rsum (coverage2 thirdparty2 tribunal2 binding2 remedy2 nonstate2 preliminary2)

tab DS_sum1
tab DS_sum2

egen DS_sum= rowmax(DS_sum1 DS_sum2)
gen DS_sum_st = DS_sum/7

drop if ionumber==.

tab DS_sum
tab DS_sum_st

label var DS_sum1 "Dispute settlement mechanism 1 (0-7)"
label var DS_sum2 "Dispute settlement mechanism 2 (0-7)"
label var DS_sum "Dispute settlement (highest) (0-7)"
label var DS_sum_st "Dispute settlement (highest) (0-1)"
*****************************************************************************************

**COMPONENT 2 of delegation: DELEGATION TO POLITICAL NON-STATE BODIES: AGENDA SETTING
*We conceive of agenda setting and final decision as motivated by different logics. 
*Agenda setting is determined by the capacity to put issues on the agenda. 
*This means that we cast our net wide to include ALL delegated bodies, full or partial, and
*conceive of them IN RELATION to the interstate bodies 
****************************************************************************************

*Step 1: Delegation is a matter of degree rather than an on/off switch: assess the non-state authority for each body//
* use Q Ax.1 for assembly, and Q Ex.8 for executive/// Each body receives a COMPOSITION SCORE
*GS is conceived to be automatically "fully delegated" 

gen A1_1d=1 if A1_1==3
replace A1_1d=0.66 if A1_1==2
replace A1_1d=0.33 if A1_1==1
replace A1_1d=0 if A1_1==0

gen A2_1d=1 if A2_1==3
replace A2_1d=0.66 if A2_1==2
replace A2_1d=0.33 if A2_1==1
replace A2_1d=0 if A2_1==0

gen A3_1d=1 if A3_1==3
replace A3_1d=0.66 if A3_1==2
replace A3_1d=0.33 if A3_1==1
replace A3_1d=0 if A3_1==0

tab A1_1d, missing
tab A2_1d, missing
tab A3_1d, missing

gen E1_8d=1 if E1_8==2
replace E1_8d=0.33 if E1_8==1
replace E1_8d=0 if E1_8==0
replace E1_8d=0 if E1_8==99

gen E2_8d=1 if E2_8==2
replace E2_8d=0.33 if E2_8==1
replace E2_8d=0 if E2_8==0

gen E3_8d=1 if E3_8==2
replace E3_8d=0.33 if E3_8==1
replace E3_8d=0 if E3_8==0

tab E1_8d, missing
tab E2_8d, missing
tab E3_8d, missing

gen CB1_15d=1 if CB1_15==1| CB1_15==2| CB1_15==3| CB1_15==4

gen CB2_15d=1 if CB2_15==1| CB2_15==2| CB2_15==3| CB2_15==4

gen CB3_15d=1 if CB3_15==4| CB3_15==3|CB3_15==2|CB3_15==1

tab CB1_15d, missing
tab CB2_15d, missing
tab CB3_15d, missing

gen GS1_10d=1 if GS1_10!=.| GS1_10_rotation==1
gen GS2_10d=1 if GS2_10!=.| GS2_10_rotation==1

tab GS1_10d, missing
tab GS2_10d, missing

*Step 2: since we cast our net wide, we consider all bodies in agenda setting for each decision area: 
*here we allocate the "delegation value" derived in the previous step to all bodies that play a role in a given decision area
*so also interstate bodies, which get a score of zero (because they do not have delegation)
*We have up to five policy streams, and while we need to look at all, we will need to pair it down to one set of scores for policy making. 
* We choose to average (see step 4) across all living policy streams because that is more robust (less vulnerable to deviations) than taking either the highest or lowest score. 
gen ACC16a_A1d=A1_1d if ACC16a_A1!=.
gen ACC16a_A2d=A2_1d if ACC16a_A2!=.
gen ACC16a_A3d=A3_1d if ACC16a_A3!=.
gen ACC16a_E1d= E1_8d if ACC16a_E1!=.
gen ACC16a_E2d= E2_8d if ACC16a_E2!=.
gen ACC16a_E3d= E3_8d if ACC16a_E3!=.
gen ACC16a_GS1d= GS1_10d if ACC16a_GS1!=.
gen ACC16a_GS2d= GS2_10d if ACC16a_GS2!=.
gen ACC16a_MSd=0 if ACC16a_MS!=.
gen ACC16a_CB1d= CB1_15d if ACC16a_CB1!=.
gen ACC16a_CB2d= CB2_15d if ACC16a_CB2!=.
gen ACC16a_CB3d= CB3_15d if ACC16a_CB3!=.

gen SUSP18a_A1d=A1_1d if SUSP18a_A1!=.
gen SUSP18a_A2d=A2_1d if SUSP18a_A2!=.
gen SUSP18a_A3d=A3_1d if SUSP18a_A3!=.
gen SUSP18a_E1d= E1_8d if SUSP18a_E1!=.
gen SUSP18a_E2d= E2_8d if SUSP18a_E2!=.
gen SUSP18a_E3d= E3_8d if SUSP18a_E3!=.
gen SUSP18a_GS1d= GS1_10d if SUSP18a_GS1!=.
gen SUSP18a_GS2d= GS2_10d if SUSP18a_GS2!=.
gen SUSP18a_MSd=0 if SUSP18a_MS!=.
gen SUSP18a_CB1d= CB1_15d if SUSP18a_CB1!=.
gen SUSP18a_CB2d= CB2_15d if SUSP18a_CB2!=.
gen SUSP18a_CB3d= CB3_15d if SUSP18a_CB3!=.
gen SUSP18a_DSd=1 if SUSP18a_DS!=.

gen CON19a_A1d=A1_1d if CON19a_A1!=.
gen CON19a_A2d=A2_1d if CON19a_A2!=.
gen CON19a_A3d=A3_1d if CON19a_A3!=.
gen CON19a_E1d= E1_8d if CON19a_E1!=.
gen CON19a_E2d= E2_8d if CON19a_E2!=.
gen CON19a_E3d= E3_8d if CON19a_E3!=.
gen CON19a_GS1d= GS1_10d if CON19a_GS1!=.
gen CON19a_GS2d= GS2_10d if CON19a_GS2!=.
gen CON19a_MSd=0 if CON19a_MS!=.
gen CON19a_CB1d= CB1_15d if CON19a_CB1!=.
gen CON19a_CB2d= CB2_15d if CON19a_CB2!=.
gen CON19a_CB3d= CB3_15d if CON19a_CB3!=.
gen CON19a_nonstated=1 if CON19a_nonstate!=.

gen BUD22a_A1d=A1_1d if BUD22a_A1!=.
gen BUD22a_A2d=A2_1d if BUD22a_A2!=.
gen BUD22a_A3d=A3_1d if BUD22a_A3!=.
gen BUD22a_E1d= E1_8d if BUD22a_E1!=.
gen BUD22a_E2d= E2_8d if BUD22a_E2!=.
gen BUD22a_E3d= E3_8d if BUD22a_E3!=.
gen BUD22a_GS1d= GS1_10d if BUD22a_GS1!=.
gen BUD22a_GS2d= GS2_10d if BUD22a_GS2!=.
gen BUD22a_MSd=0 if BUD22a_MS!=.
gen BUD22a_CB1d= CB1_15d if BUD22a_CB1!=.
gen BUD22a_CB2d= CB2_15d if BUD22a_CB2!=.
gen BUD22a_CB3d= CB3_15d if BUD22a_CB3!=.
gen BUD22a_nonstated=1 if BUD22a_nonstate!=.

gen COM24a_A1d=A1_1d if COM24a_A1!=.
gen COM24a_A2d=A2_1d if COM24a_A2!=.
gen COM24a_A3d=A3_1d if COM24a_A3!=.
gen COM24a_E1d= E1_8d if COM24a_E1!=.
gen COM24a_E2d= E2_8d if COM24a_E2!=.
gen COM24a_E3d= E3_8d if COM24a_E3!=.
gen COM24a_GS1d= GS1_10d if COM24a_GS1!=.
gen COM24a_GS2d= GS2_10d if COM24a_GS2!=.
gen COM24a_MSd=0 if COM24a_MS!=.
gen COM24a_CB1d= CB1_15d if COM24a_CB1!=.
gen COM24a_CB2d= CB2_15d if COM24a_CB2!=.
gen COM24a_CB3d= CB3_15d if COM24a_CB3!=.

gen PM1_25a_A1d=A1_1d if PM1_25a_A1!=.
gen PM1_25a_A2d=A2_1d if PM1_25a_A2!=.
gen PM1_25a_A3d=A3_1d if PM1_25a_A3!=.
gen PM1_25a_E1d= E1_8d if PM1_25a_E1!=.
gen PM1_25a_E2d= E2_8d if PM1_25a_E2!=.
gen PM1_25a_E3d= E3_8d if PM1_25a_E3!=.
gen PM1_25a_GS1d= GS1_10d if PM1_25a_GS1!=.
gen PM1_25a_GS2d= GS2_10d if PM1_25a_GS2!=.
gen PM1_25a_MSd=0 if PM1_25a_MS!=.
gen PM1_25a_CB1d= CB1_15d if PM1_25a_CB1!=.
gen PM1_25a_CB2d= CB2_15d if PM1_25a_CB2!=.
gen PM1_25a_CB3d= CB3_15d if PM1_25a_CB3!=.
gen PM1_25a_nonstated=1 if PM1_25a_nonstate!=.

gen PM2_25a_A1d=A1_1d if PM2_25a_A1!=.
gen PM2_25a_A2d=A2_1d if PM2_25a_A2!=.
gen PM2_25a_A3d=A3_1d if PM2_25a_A3!=.
gen PM2_25a_E1d= E1_8d if PM2_25a_E1!=.
gen PM2_25a_E2d= E2_8d if PM2_25a_E2!=.
gen PM2_25a_E3d= E3_8d if PM2_25a_E3!=.
gen PM2_25a_GS1d= GS1_10d if PM2_25a_GS1!=.
gen PM2_25a_GS2d= GS2_10d if PM2_25a_GS2!=.
gen PM2_25a_MSd=0 if PM2_25a_MS!=.
gen PM2_25a_CB1d= CB1_15d if PM2_25a_CB1!=.
gen PM2_25a_CB2d= CB2_15d if PM2_25a_CB2!=.
gen PM2_25a_CB3d= CB3_15d if PM2_25a_CB3!=.
gen PM2_25a_nonstated=1 if PM2_25a_nonstate!=.

gen PM3_25a_A1d=A1_1d if PM3_25a_A1!=.
gen PM3_25a_A2d=A2_1d if PM3_25a_A2!=.
gen PM3_25a_A3d=A3_1d if PM3_25a_A3!=.
gen PM3_25a_E1d= E1_8d if PM3_25a_E1!=.
gen PM3_25a_E2d= E2_8d if PM3_25a_E2!=.
gen PM3_25a_E3d= E3_8d if PM3_25a_E3!=.
gen PM3_25a_GS1d= GS1_10d if PM3_25a_GS1!=.
gen PM3_25a_GS2d= GS2_10d if PM3_25a_GS2!=.
gen PM3_25a_MSd=0 if PM3_25a_MS!=.
gen PM3_25a_CB1d= CB1_15d if PM3_25a_CB1!=.
gen PM3_25a_CB2d= CB2_15d if PM3_25a_CB2!=.
gen PM3_25a_CB3d= CB3_15d if PM3_25a_CB3!=.
gen PM3_25a_nonstated=1 if PM3_25a_nonstate!=.

gen PM4_25a_A1d=A1_1d if PM4_25a_A1!=.
gen PM4_25a_A2d=A2_1d if PM4_25a_A2!=.
gen PM4_25a_A3d=A3_1d if PM4_25a_A3!=.
gen PM4_25a_E1d= E1_8d if PM4_25a_E1!=.
gen PM4_25a_E2d= E2_8d if PM4_25a_E2!=.
gen PM4_25a_E3d= E3_8d if PM4_25a_E3!=.
gen PM4_25a_GS1d= GS1_10d if PM4_25a_GS1!=.
gen PM4_25a_GS2d= GS2_10d if PM4_25a_GS2!=.
gen PM4_25a_MSd=0 if PM4_25a_MS!=.
gen PM4_25a_CB1d= CB1_15d if PM4_25a_CB1!=.
gen PM4_25a_CB2d= CB2_15d if PM4_25a_CB2!=.
gen PM4_25a_CB3d= CB3_15d if PM4_25a_CB3!=.
gen PM4_25a_nonstated=1 if PM4_25a_nonstate!=.

gen PM5_25a_A1d=A1_1d if PM5_25a_A1!=.
gen PM5_25a_A2d=A2_1d if PM5_25a_A2!=.
gen PM5_25a_A3d=A3_1d if PM5_25a_A3!=.
gen PM5_25a_E1d= E1_8d if PM5_25a_E1!=.
gen PM5_25a_E2d= E2_8d if PM5_25a_E2!=.
gen PM5_25a_E3d= E3_8d if PM5_25a_E3!=.
gen PM5_25a_GS1d= GS1_10d if PM5_25a_GS1!=.
gen PM5_25a_GS2d= GS2_10d if PM5_25a_GS2!=.
gen PM5_25a_MSd=0 if PM5_25a_MS!=.
gen PM5_25a_CB1d= CB1_15d if PM5_25a_CB1!=.
gen PM5_25a_CB2d= CB2_15d if PM5_25a_CB2!=.
gen PM5_25a_CB3d= CB3_15d if PM5_25a_CB3!=.
gen PM5_25a_nonstated=1 if PM5_25a_nonstate!=.

* Step 3: calculate delegation in agenda setting for each decision area (except for policy making):
*we average scores for ALL bodies involved in a decision to get a read of the average delegated authority: 
*the score can be high for two reasons: there are a lot of delegated bodies relative to state bodies and/or these delegated bodies are strong delegated bodies (high score in step 1)
egen A_ACCa= rmean (ACC16a_A1d  ACC16a_A2d ACC16a_A1d ACC16a_A3d ACC16a_E1d ACC16a_E2d ACC16a_E3d ACC16a_GS1d ACC16a_GS2d ACC16a_MSd ACC16a_CB1d ACC16a_CB2d ACC16a_CB3d)
egen A_SUSPa=rmean (SUSP18a_A1d  SUSP18a_A2d SUSP18a_A1d SUSP18a_A3d SUSP18a_E1d SUSP18a_E2d SUSP18a_E3d SUSP18a_GS1d SUSP18a_GS2d SUSP18a_MSd SUSP18a_CB1d SUSP18a_CB2d SUSP18a_CB3d SUSP18a_DSd)
egen A_CONa= rmean (CON19a_A1d  CON19a_A2d CON19a_A1d CON19a_A3d CON19a_E1d CON19a_E2d CON19a_E3d CON19a_GS1d CON19a_GS2d CON19a_MSd CON19a_CB1d CON19a_CB2d CON19a_CB3d CON19a_nonstated)
egen A_BUDa= rmean (BUD22a_A1d  BUD22a_A2d BUD22a_A1d BUD22a_A3d BUD22a_E1d BUD22a_E2d BUD22a_E3d BUD22a_GS1d BUD22a_GS2d BUD22a_MSd BUD22a_CB1d BUD22a_CB2d BUD22a_CB3d BUD22a_nonstated)
egen A_COMa= rmean (COM24a_A1d  COM24a_A2d COM24a_A1d COM24a_A3d COM24a_E1d COM24a_E2d COM24a_E3d COM24a_GS1d COM24a_GS2d COM24a_MSd COM24a_CB1d COM24a_CB2d COM24a_CB3d)


*Step 4: Let's now calculate delegation in agenda setting for policy making. First, calculate average delegation in each stream. Second, take account of the possibility monopoly of initiative. If monopoly, multiply by 1. Otherwise keep old score.
*Clearly, if a delegated body has the monopoly of initiative in an area, that is important. Empirically this is only a real option for a GS and only in one of the six areas: policy making.
*We give this power a pretty heavy weight (the max of 1) and we average this, where it occurs, with the delegation score for all other bodies. And finally, aggregate (i.e. average) from the up-to-five streams.

egen A_PM1a= rmean (PM1_25a_A1d  PM1_25a_A2d PM1_25a_A1d PM1_25a_A3d PM1_25a_E1d PM1_25a_E2d PM1_25a_E3d PM1_25a_GS1d PM1_25a_GS2d PM1_25a_MSd PM1_25a_CB1d PM1_25a_CB2d PM1_25a_CB3d PM1_25a_nonstated)
egen A_PM2a= rmean (PM2_25a_A1d  PM2_25a_A2d PM2_25a_A1d PM2_25a_A3d PM2_25a_E1d PM2_25a_E2d PM2_25a_E3d PM2_25a_GS1d PM2_25a_GS2d PM2_25a_MSd PM2_25a_CB1d PM2_25a_CB2d PM2_25a_CB3d PM2_25a_nonstated)
egen A_PM3a= rmean (PM3_25a_A1d  PM3_25a_A2d PM3_25a_A1d PM3_25a_A3d PM3_25a_E1d PM3_25a_E2d PM3_25a_E3d PM3_25a_GS1d PM3_25a_GS2d PM3_25a_MSd PM3_25a_CB1d PM3_25a_CB2d PM3_25a_CB3d PM3_25a_nonstated)
egen A_PM4a= rmean (PM4_25a_A1d  PM4_25a_A2d PM4_25a_A1d PM4_25a_A3d PM4_25a_E1d PM4_25a_E2d PM4_25a_E3d PM4_25a_GS1d PM4_25a_GS2d PM4_25a_MSd PM4_25a_CB1d PM4_25a_CB2d PM4_25a_CB3d PM4_25a_nonstated)
egen A_PM5a= rmean (PM5_25a_A1d  PM5_25a_A2d PM5_25a_A1d PM5_25a_A3d PM5_25a_E1d PM5_25a_E2d PM5_25a_E3d PM5_25a_GS1d PM5_25a_GS2d PM5_25a_MSd PM5_25a_CB1d PM5_25a_CB2d PM5_25a_CB3d PM5_25a_nonstated)


foreach x of varlist PM1_25c PM2_25c PM3_25c PM4_25c PM5_25c{
gen `x'd = .
replace `x'd = 0 if `x'==0
replace `x'd = 0 if `x'==1
replace `x'd = 1 if `x'==2
replace `x'd = 0 if `x'==99
replace `x'd = 0 if `x'==98
}
tab PM1_25cd 
tab PM2_25cd 
tab PM3_25cd 
tab PM4_25cd 
tab PM5_25cd

gen A_PM1a1=A_PM1a
replace A_PM1a1=(A_PM1a + PM1_25cd)/2 if PM1_25cd==1
gen A_PM2a1=A_PM2a
replace A_PM2a1=(A_PM2a + PM2_25cd)/2 if PM2_25cd==1
gen A_PM3a1=A_PM3a
replace A_PM3a1=(A_PM3a + PM3_25cd)/2 if PM3_25cd==1
gen A_PM4a1=A_PM4a
replace A_PM4a1=(A_PM4a + PM4_25cd)/2 if PM4_25cd==1
gen A_PM5a1=A_PM5a
replace A_PM5a1=(A_PM5a + PM5_25cd)/2 if PM5_25cd==1

*and now, finally, average delegation for policy making, having taken into account the up-to-five streams as well as monopoly of initiative! 

egen A_PMa= rmean (A_PM1a1 A_PM2a1 A_PM3a1 A_PM4a1 A_PM5a1)

*Step 5: Now aggregate delegation across all decision areas for agenda setting
*First turn all missing values into zero (because MV means there is no delegation it is best to put these to zero) -- and for good measure, we run some descriptives
replace A_ACCa=0 if A_ACCa==.
replace A_SUSPa=0 if A_SUSPa==.
replace A_CONa=0 if A_CONa==.
replace A_BUDa=0 if A_BUDa==.
replace A_COMa=0 if A_COMa==.
replace A_PMa=0 if A_PMa==.

tab A_ACCa
tab A_SUSPa
tab A_CONa
tab A_BUDa
tab A_COMa
tab A_PMa

*Next aggregate to estimate delegation in agenda setting across all decision areas; scale back to 0-1; and descriptives
gen del_agenda= (A_ACCa + A_SUSPa + A_CONa + A_BUDa + A_COMa + A_PMa)/6

corr A_ACCa A_SUSPa A_CONa A_BUDa A_COMa A_PMa del_agenda

tab del_agenda
tabstat A_ACCa A_SUSPa A_CONa A_BUDa A_COMa A_PMa del_agenda, stats (min max mean p25 p75)
drop del_agenda


*****************************************************************************
*COMPONENT 3 of delegation: DELEGATION OF POLITICAL BODIES IN FINAL DECISION
*We conceive of agenda setting and final decision as motivated by different logics: agenda-setting is inclusive,
* while final decision making is about who can pull the plug. We are interested in the most delegated body because it
* has the greatest potential to be a key game changer in an otherwise interstate game.
*****************************************************************************

* Step 1: Score all bodies in final decision for each decision area: which one is the most delegated, so we need a lay of the land.
gen ACC16b_A1d=A1_1d if ACC16b_A1!=.
gen ACC16b_A2d=A2_1d if ACC16b_A2!=.
gen ACC16b_A3d=A3_1d if ACC16b_A3!=.
gen ACC16b_E1d= E1_8d if ACC16b_E1!=.
gen ACC16b_E2d= E2_8d if ACC16b_E2!=.
gen ACC16b_E3d= E3_8d if ACC16b_E3!=.
gen ACC16b_GS1d= GS1_10d if ACC16b_GS1!=.
gen ACC16b_GS2d= GS2_10d if ACC16b_GS2!=.
gen ACC16b_MSd=0 if ACC16b_MS!=.
gen ACC16b_CB1d= CB1_15d if ACC16b_CB1!=.
gen ACC16b_CB2d= CB2_15d if ACC16b_CB2!=.
gen ACC16b_CB3d= CB3_15d if ACC16b_CB3!=.

gen SUSP18b_A1d=A1_1d if SUSP18b_A1!=.
gen SUSP18b_A2d=A2_1d if SUSP18b_A2!=.
gen SUSP18b_A3d=A3_1d if SUSP18b_A3!=.
gen SUSP18b_E1d= E1_8d if SUSP18b_E1!=.
gen SUSP18b_E2d= E2_8d if SUSP18b_E2!=.
gen SUSP18b_E3d= E3_8d if SUSP18b_E3!=.
gen SUSP18b_GS1d= GS1_10d if SUSP18b_GS1!=.
gen SUSP18b_GS2d= GS2_10d if SUSP18b_GS2!=.
gen SUSP18b_MSd=0 if SUSP18b_MS!=.
gen SUSP18b_CB1d= CB1_15d if SUSP18b_CB1!=.
gen SUSP18b_CB2d= CB2_15d if SUSP18b_CB2!=.
gen SUSP18b_CB3d= CB3_15d if SUSP18b_CB3!=.
gen SUSP18b_DSd=1 if SUSP18a_DS!=.

gen CON19b_A1d=A1_1d if CON19b_A1!=.
gen CON19b_A2d=A2_1d if CON19b_A2!=.
gen CON19b_A3d=A3_1d if CON19b_A3!=.
gen CON19b_E1d= E1_8d if CON19b_E1!=.
gen CON19b_E2d= E2_8d if CON19b_E2!=.
gen CON19b_E3d= E3_8d if CON19b_E3!=.
gen CON19b_GS1d= GS1_10d if CON19b_GS1!=.
gen CON19b_GS2d= GS2_10d if CON19b_GS2!=.
gen CON19b_MSd=0 if CON19b_MS!=.
gen CON19b_CB1d= CB1_15d if CON19b_CB1!=.
gen CON19b_CB2d= CB2_15d if CON19b_CB2!=.
gen CON19b_CB3d= CB3_15d if CON19b_CB3!=.

gen BUD22b_A1d=A1_1d if BUD22b_A1!=.
gen BUD22b_A2d=A2_1d if BUD22b_A2!=.
gen BUD22b_A3d=A3_1d if BUD22b_A3!=.
gen BUD22b_E1d= E1_8d if BUD22b_E1!=.
gen BUD22b_E2d= E2_8d if BUD22b_E2!=.
gen BUD22b_E3d= E3_8d if BUD22b_E3!=.
gen BUD22b_GS1d= GS1_10d if BUD22b_GS1!=.
gen BUD22b_GS2d= GS2_10d if BUD22b_GS2!=.
gen BUD22b_MSd=0 if BUD22b_MS!=.
gen BUD22b_CB1d= CB1_15d if BUD22b_CB1!=.
gen BUD22b_CB2d= CB2_15d if BUD22b_CB2!=.
gen BUD22b_CB3d= CB3_15d if BUD22b_CB3!=.

gen COM24b_A1d=A1_1d if COM24b_A1!=.
gen COM24b_A2d=A2_1d if COM24b_A2!=.
gen COM24b_A3d=A3_1d if COM24b_A3!=.
gen COM24b_E1d= E1_8d if COM24b_E1!=.
gen COM24b_E2d= E2_8d if COM24b_E2!=.
gen COM24b_E3d= E3_8d if COM24b_E3!=.
gen COM24b_GS1d= GS1_10d if COM24b_GS1!=.
gen COM24b_GS2d= GS2_10d if COM24b_GS2!=.
gen COM24b_MSd=0 if COM24b_MS!=.
gen COM24b_CB1d= CB1_15d if COM24b_CB1!=.
gen COM24b_CB2d= CB2_15d if COM24b_CB2!=.
gen COM24b_CB3d= CB3_15d if COM24b_CB3!=.

gen PM1_25b_A1d=A1_1d if PM1_25b_A1!=.
gen PM1_25b_A2d=A2_1d if PM1_25b_A2!=.
gen PM1_25b_A3d=A3_1d if PM1_25b_A3!=.
gen PM1_25b_E1d= E1_8d if PM1_25b_E1!=.
gen PM1_25b_E2d= E2_8d if PM1_25b_E2!=.
gen PM1_25b_E3d= E3_8d if PM1_25b_E3!=.
gen PM1_25b_GS1d= GS1_10d if PM1_25b_GS1!=.
gen PM1_25b_GS2d= GS2_10d if PM1_25b_GS2!=.
gen PM1_25b_MSd=0 if PM1_25b_MS!=.
gen PM1_25b_CB1d= CB1_15d if PM1_25b_CB1!=.
gen PM1_25b_CB2d= CB2_15d if PM1_25b_CB2!=.
gen PM1_25b_CB3d= CB3_15d if PM1_25b_CB3!=.
gen PM1_25b_nonstated=1 if PM1_25b_nonstate!=.

gen PM2_25b_A1d=A1_1d if PM2_25b_A1!=.
gen PM2_25b_A2d=A2_1d if PM2_25b_A2!=.
gen PM2_25b_A3d=A3_1d if PM2_25b_A3!=.
gen PM2_25b_E1d= E1_8d if PM2_25b_E1!=.
gen PM2_25b_E2d= E2_8d if PM2_25b_E2!=.
gen PM2_25b_E3d= E3_8d if PM2_25b_E3!=.
gen PM2_25b_GS1d= GS1_10d if PM2_25b_GS1!=.
gen PM2_25b_GS2d= GS2_10d if PM2_25b_GS2!=.
gen PM2_25b_MSd=0 if PM2_25b_MS!=.
gen PM2_25b_CB1d= CB1_15d if PM2_25b_CB1!=.
gen PM2_25b_CB2d= CB2_15d if PM2_25b_CB2!=.
gen PM2_25b_CB3d= CB3_15d if PM2_25b_CB3!=.
gen PM2_25b_nonstated=1 if PM2_25b_nonstate!=.

gen PM3_25b_A1d=A1_1d if PM3_25b_A1!=.
gen PM3_25b_A2d=A2_1d if PM3_25b_A2!=.
gen PM3_25b_A3d=A3_1d if PM3_25b_A3!=.
gen PM3_25b_E1d= E1_8d if PM3_25b_E1!=.
gen PM3_25b_E2d= E2_8d if PM3_25b_E2!=.
gen PM3_25b_E3d= E3_8d if PM3_25b_E3!=.
gen PM3_25b_GS1d= GS1_10d if PM3_25b_GS1!=.
gen PM3_25b_GS2d= GS2_10d if PM3_25b_GS2!=.
gen PM3_25b_MSd=0 if PM3_25b_MS!=.
gen PM3_25b_CB1d= CB1_15d if PM3_25b_CB1!=.
gen PM3_25b_CB2d= CB2_15d if PM3_25b_CB2!=.
gen PM3_25b_CB3d= CB3_15d if PM3_25b_CB3!=.
gen PM3_25b_nonstated=1 if PM3_25b_nonstate!=.

gen PM4_25b_A1d=A1_1d if PM4_25b_A1!=.
gen PM4_25b_A2d=A2_1d if PM4_25b_A2!=.
gen PM4_25b_A3d=A3_1d if PM4_25b_A3!=.
gen PM4_25b_E1d= E1_8d if PM4_25b_E1!=.
gen PM4_25b_E2d= E2_8d if PM4_25b_E2!=.
gen PM4_25b_E3d= E3_8d if PM4_25b_E3!=.
gen PM4_25b_GS1d= GS1_10d if PM4_25b_GS1!=.
gen PM4_25b_GS2d= GS2_10d if PM4_25b_GS2!=.
gen PM4_25b_MSd=0 if PM4_25b_MS!=.
gen PM4_25b_CB1d= CB1_15d if PM4_25b_CB1!=.
gen PM4_25b_CB2d= CB2_15d if PM4_25b_CB2!=.
gen PM4_25b_CB3d= CB3_15d if PM4_25b_CB3!=.
gen PM4_25b_nonstated=1 if PM4_25b_nonstate!=.

gen PM5_25b_A1d=A1_1d if PM5_25b_A1!=.
gen PM5_25b_A2d=A2_1d if PM5_25b_A2!=.
gen PM5_25b_A3d=A3_1d if PM5_25b_A3!=.
gen PM5_25b_E1d= E1_8d if PM5_25b_E1!=.
gen PM5_25b_E2d= E2_8d if PM5_25b_E2!=.
gen PM5_25b_E3d= E3_8d if PM5_25b_E3!=.
gen PM5_25b_GS1d= GS1_10d if PM5_25b_GS1!=.
gen PM5_25b_GS2d= GS2_10d if PM5_25b_GS2!=.
gen PM5_25b_MSd=0 if PM5_25b_MS!=.
gen PM5_25b_CB1d= CB1_15d if PM5_25b_CB1!=.
gen PM5_25b_CB2d= CB2_15d if PM5_25b_CB2!=.
gen PM5_25b_CB3d= CB3_15d if PM5_25b_CB3!=.
gen PM5_25b_nonstated=1 if PM5_25b_nonstate!=.

*Step 2: Zoom into the highest scorer in delegation in final decision making, and do this for each decision area!
*As before, we have five policy streams, and we proceed in two steps: first identify the most delegated body in each stream, and then take the average across living streams.
*The average is more robust than taking the max value. 
egen A_ACCb= rmax(ACC16b_A1d  ACC16b_A2d ACC16b_A1d ACC16b_A3d ACC16b_E1d ACC16b_E2d ACC16b_E3d ACC16b_GS1d ACC16b_GS2d ACC16b_MSd ACC16b_CB1d ACC16b_CB2d ACC16b_CB3d)
egen A_SUSPb= rmax (SUSP18b_A1d  SUSP18b_A2d SUSP18b_A1d SUSP18b_A3d SUSP18b_E1d SUSP18b_E2d SUSP18b_E3d SUSP18b_GS1d SUSP18b_GS2d SUSP18b_MSd SUSP18b_CB1d SUSP18b_CB2d SUSP18b_CB3d SUSP18b_DSd)
egen A_CONb= rmax (CON19b_A1d  CON19b_A2d CON19b_A1d CON19b_A3d CON19b_E1d CON19b_E2d CON19b_E3d CON19b_GS1d CON19b_GS2d CON19b_MSd CON19b_CB1d CON19b_CB2d CON19b_CB3d)
egen A_BUDb= rmax (BUD22b_A1d  BUD22b_A2d BUD22b_A1d BUD22b_A3d BUD22b_E1d BUD22b_E2d BUD22b_E3d BUD22b_GS1d BUD22b_GS2d BUD22b_MSd BUD22b_CB1d BUD22b_CB2d BUD22b_CB3d)
egen A_COMb= rmax (COM24b_A1d  COM24b_A2d COM24b_A1d COM24b_A3d COM24b_E1d COM24b_E2d COM24b_E3d COM24b_GS1d COM24b_GS2d COM24b_MSd COM24b_CB1d COM24b_CB2d COM24b_CB3d)

egen A_PM1b= rmax (PM1_25b_A1d  PM1_25b_A2d PM1_25b_A1d PM1_25b_A3d PM1_25b_E1d PM1_25b_E2d PM1_25b_E3d PM1_25b_GS1d PM1_25b_GS2d PM1_25b_MSd PM1_25b_CB1d PM1_25b_CB2d PM1_25b_CB3d PM1_25b_nonstated)
egen A_PM2b= rmax (PM2_25b_A1d  PM2_25b_A2d PM2_25b_A1d PM2_25b_A3d PM2_25b_E1d PM2_25b_E2d PM2_25b_E3d PM2_25b_GS1d PM2_25b_GS2d PM2_25b_MSd PM2_25b_CB1d PM2_25b_CB2d PM2_25b_CB3d PM2_25b_nonstated)
egen A_PM3b= rmax (PM3_25b_A1d  PM3_25b_A2d PM3_25b_A1d PM3_25b_A3d PM3_25b_E1d PM3_25b_E2d PM3_25b_E3d PM3_25b_GS1d PM3_25b_GS2d PM3_25b_MSd PM3_25b_CB1d PM3_25b_CB2d PM3_25b_CB3d PM3_25b_nonstated)
egen A_PM4b= rmax (PM4_25b_A1d  PM4_25b_A2d PM4_25b_A1d PM4_25b_A3d PM4_25b_E1d PM4_25b_E2d PM4_25b_E3d PM4_25b_GS1d PM4_25b_GS2d PM4_25b_MSd PM4_25b_CB1d PM4_25b_CB2d PM4_25b_CB3d PM4_25b_nonstated)
egen A_PM5b= rmax (PM5_25b_A1d  PM5_25b_A2d PM5_25b_A1d PM5_25b_A3d PM5_25b_E1d PM5_25b_E2d PM5_25b_E3d PM5_25b_GS1d PM5_25b_GS2d PM5_25b_MSd PM5_25b_CB1d PM5_25b_CB2d PM5_25b_CB3d PM5_25b_nonstated)

egen A_PMb=rmean (A_PM1b A_PM2b A_PM3b A_PM4b A_PM5b)


*Step 3: Aggregate to estimate delegation in the final decision
*First get rid of missing values by turning them into zero; some descriptives
replace A_ACCb=0 if A_ACCb==.
replace A_SUSPb=0 if A_SUSPb==.
replace A_CONb=0 if A_CONb==.
replace A_BUDb=0 if A_BUDb==.
replace A_COMb=0 if A_COMb==.
replace A_PMb=0 if A_PMb==.

tab A_ACCb
tab A_SUSPb
tab A_CONb
tab A_BUDb
tab A_COMb
tab A_PMb

*Now aggregate, and some descriptives
gen del_final= (A_ACCb + A_SUSPb + A_CONb + A_BUDb + A_COMb + A_PMb)/6

corr A_ACCb A_SUSPb A_CONb A_BUDb A_COMb A_PMb del_final

tabstat A_ACCb A_SUSPb A_CONb A_BUDb A_COMb A_PMb del_final, stats (min max mean p25 p75)
drop del_final


*****************************************************
*AGGREGATION by decision area with equal weight for agenda setting and final decision

*just have another look at the basic Lego blocs:
tab A_ACCa
tab A_ACCb
tab A_SUSPa
tab A_SUSPb
tab A_CONa
tab A_CONb
tab A_BUDa
tab A_BUDb
tab A_COMa
tab A_COMb
tab A_PMa
tab A_PMb

corr A_ACCa A_ACCb A_SUSPa A_SUSPb A_CONa A_CONb A_BUDa A_BUDb A_COMa A_COMb A_PMa A_PMb

*Now aggregate by decision area (add dispute settlement which applies across all areas)
gen delaccess = (A_ACCa + A_ACCb + DS_sum_st)/3
gen delsuspens= (A_SUSPa + A_SUSPb + DS_sum_st)/3
gen delconstit = (A_CONa + A_CONb + DS_sum_st)/3
gen delbudget = (A_BUDa + A_BUDb + DS_sum_st)/3
gen delfincompl = (A_COMa + A_COMb + DS_sum_st)/3
gen delpolicy = (A_PMa + A_PMb + DS_sum_st)/3
gen delegation6 = (delaccess + delsuspens + delconstit + delbudget + delfincompl + delpolicy)/6
corr delaccess delsuspens delconstit delbudget delfincompl delpolicy delegation6

*Or aggregate by decision stage
gen del_agenda= (A_ACCa + A_SUSPa + A_CONa + A_BUDa + A_COMa + A_PMa)/6
gen del_final=(A_ACCb + A_SUSPb + A_CONb + A_BUDb + A_COMb + A_PMb)/6

*Now the final delegation score: bring the three pillars together: agenda setting, final decision, dispute settlement 
gen delegation3 = (del_agenda + del_final + DS_sum_st)/3
tab del_agenda
tab del_final
tab DS_sum_st
corr del_agenda del_final DS_sum_st delegation6

corr delegation3 delegation6
*delegation3 and delegation6 should be identical*


label var del_agenda "delegation on agenda setting (0-1)"
label var del_final "delegation on final decision (0-1)"
label var delegation3 "delegation (0-1) aggregating agenda, final, DS"
label var delegation6 "delegation (0-1) aggregating by decision area"
label var delaccess "delegation on accession (A,F,DS)"
label var delsuspens "delegation on suspension (A,F,DS)"
label var delconstit "delegation on constitution (A,F,DS)"
label var delbudget "delegation on budget (A,F,DS)"
label var delfincompl "delegation on fin compliance (A,F,DS)"
label var delpolicy "delegation on policy (A,F,DS)"
label var DS_sum_st "delegation to dispute settlement (0-1)"

***************************************************************************************************************
***************************************************************************************************************



**************************************************************************
							*measuring pooling*
							
**************************************************************************
*Critical information on pooling is a) whether a body is interstate or not, b) its decision rule, b) whether it can take binding decisions and/or its decisions are subject to ratification
*Pooling focuses on interstate bodies, but there are a number of hybrid bodies -- those which have a small element of delegation 
* (e.g. because the head is nonstate), but that are predominantly interstate. In technical terms, these are assemblies or executives that 
*did not score a perfect zero on Ax_1 or Ex_8. Our first step is to bring these bodies back into the analysis.

*PRELIMINARY STEP: select assemblies and executives that are dominated by member states*
gen A1_ms = 0
replace A1_ms = 1 if A1_1==0| A1_1==1
gen A2_ms = 0
replace A2_ms = 1 if A2_1==0| A2_1==1
gen A3_ms = 0
replace A3_ms = 1 if A3_1==0| A3_1==1

gen ass_MS = A1_ms + A2_ms + A3_ms

gen E1_ms = 0
replace E1_ms = 1 if E1_8==0| E1_8==1 
replace E1_ms = 1 if ioname=="ILO"
replace E1_ms = 0 if ioname=="IGAD" & year>1994
gen E2_ms = 0
replace E2_ms = 1 if E2_8==0| E2_8==1
gen E3_ms = 0
replace E3_ms = 1 if E3_8==0| E3_8==1

**Note on ILO: Council is a uniquely mixed interstate/ non-state body which we include here as interstate (despite E1_8=2)
**Note on IGAD Secretariat is uniquely ambivalent in its independence (E1_8=1), but is not an interstate body

***************************************************************************************************************
*POOLING IN AGENDA SETTING**
*This is an inclusive step: which are the interstate bodies involved in agenda setting, and how "pooled" are they?
***************************************************************************************************************
*STEP 1: Which bodies are involved in agenda-setting?*
*generate pooling variables*
foreach x of varlist ACC16a_A1 ACC16a_A2 ACC16a_A3 ACC16a_E1 ACC16a_E2 ACC16a_E3 ACC16a_MS ///
SUSP18a_A1 SUSP18a_A2 SUSP18a_A3 SUSP18a_E1 SUSP18a_E2 SUSP18a_E3 SUSP18a_MS ///
CON19a_A1 CON19a_A2 CON19a_A3 CON19a_E1 CON19a_E2 CON19a_E3 CON19a_MS ///
BUD22a_A1 BUD22a_A2 BUD22a_A3 BUD22a_E1 BUD22a_E2 BUD22a_E3 BUD22a_MS ///
COM24a_A1 COM24a_A2 COM24a_A3 COM24a_E1 COM24a_E2 COM24a_E3 COM24a_MS ///
PM1_25a_A1 PM1_25a_A2 PM1_25a_A3 PM1_25a_E1 PM1_25a_E2 PM1_25a_E3 PM1_25a_MS ///
PM2_25a_A1 PM2_25a_A2 PM2_25a_A3 PM2_25a_E1 PM2_25a_E2 PM2_25a_E3 PM2_25a_MS ///
PM3_25a_A1 PM3_25a_A2 PM3_25a_A3 PM3_25a_E1 PM3_25a_E2 PM3_25a_E3 PM3_25a_MS ///
PM4_25a_A1 PM4_25a_A2 PM4_25a_A3 PM4_25a_E1 PM4_25a_E2 PM4_25a_E3 PM4_25a_MS ///
PM5_25a_A1 PM5_25a_A2 PM5_25a_A3 PM5_25a_E1 PM5_25a_E2 PM5_25a_E3 PM5_25a_MS{
gen `x'p = .
}

*STEP 2: VOTING RULE: What is their decision rule? Let pooling variables take on the values of originals if body is MS dominated*
foreach x of varlist ACC16a_A1 SUSP18a_A1 CON19a_A1 BUD22a_A1 COM24a_A1 ///
PM1_25a_A1 PM2_25a_A1 PM3_25a_A1 PM4_25a_A1 PM4_25a_A1{
replace `x'p = `x' if A1_ms==1            
}

foreach x of varlist ACC16a_A2 SUSP18a_A2 CON19a_A2 BUD22a_A2 COM24a_A2 ///
PM1_25a_A2 PM2_25a_A2 PM3_25a_A2 PM4_25a_A2 PM5_25a_A2{
replace `x'p = `x' if A2_ms==1            
}

foreach x of varlist ACC16a_A3 SUSP18a_A3 CON19a_A3 BUD22a_A3 COM24a_A3 ///
PM1_25a_A3 PM2_25a_A3 PM3_25a_A3 PM4_25a_A3 PM5_25a_A3{
replace `x'p = `x' if A3_ms==1            
}

foreach x of varlist ACC16a_E1 SUSP18a_E1 CON19a_E1 BUD22a_E1 COM24a_E1 ///
PM1_25a_E1 PM2_25a_E1 PM3_25a_E1 PM4_25a_E1 PM5_25a_E1{
replace `x'p = `x' if E1_ms==1            
}

foreach x of varlist ACC16a_E2 SUSP18a_E2 CON19a_E2 BUD22a_E2 COM24a_E2 ///
PM1_25a_E2 PM2_25a_E2 PM3_25a_E2 PM4_25a_E2 PM5_25a_E2{
replace `x'p = `x' if E2_ms==1            
}

foreach x of varlist ACC16a_E3 SUSP18a_E3 CON19a_E3 BUD22a_E3 COM24a_E3 ///
PM1_25a_E3 PM2_25a_E3 PM3_25a_E3 PM4_25a_E3 PM5_25a_E3{
replace `x'p = `x' if E3_ms==1            
}  

*STEP 3: Now recode decision rules on a 0-1 scale in several steps. 
**First, take into account weighted voting
**Next recode decision rules*
foreach x of varlist ACC16a_A1 SUSP18a_A1 CON19a_A1 BUD22a_A1 COM24a_A1 PM1_25a_A1 PM2_25a_A1 PM3_25a_A1 PM4_25a_A1 PM5_25a_A1{
recode `x'p (3 = 2) if A1_3a==1
}

foreach x of varlist ACC16a_E1 SUSP18a_E1 CON19a_E1 BUD22a_E1 COM24a_E1 PM1_25a_E1 PM2_25a_E1 PM3_25a_E1 PM4_25a_E1 PM5_25a_E1{
recode `x'p (3 = 2) if E1_9b==1
}

foreach x of varlist ACC16a_E2 SUSP18a_E2 CON19a_E2 BUD22a_E2 COM24a_E2 PM1_25a_E2 PM2_25a_E2 PM3_25a_E2 PM4_25a_E2 PM5_25a_E2{
recode `x'p (3 = 2) if E2_9b==1
}
foreach x of varlist ACC16a_E3 SUSP18a_E3 CON19a_E3 BUD22a_E3 COM24a_E3 PM1_25a_E3 PM2_25a_E3 PM3_25a_E3 PM4_25a_E3 PM5_25a_E3{
recode `x'p (3 = 2) if E3_9b==1
}
foreach x of varlist ACC16a_A1 ACC16a_A2 ACC16a_A3 ACC16a_E1 ACC16a_E2 ACC16a_E3 ///
SUSP18a_A1 SUSP18a_A2 SUSP18a_A3 SUSP18a_E1 SUSP18a_E2 SUSP18a_E3 ///
CON19a_A1 CON19a_A2 CON19a_A3 CON19a_E1 CON19a_E2 CON19a_E3 ///
BUD22a_A1 BUD22a_A2 BUD22a_A3 BUD22a_E1 BUD22a_E2 BUD22a_E3 ///
COM24a_A1 COM24a_A2 COM24a_A3 COM24a_E1 COM24a_E2 COM24a_E3 ///
PM1_25a_A1 PM1_25a_A2 PM1_25a_A3 PM1_25a_E1 PM1_25a_E2 PM1_25a_E3 ///
PM2_25a_A1 PM2_25a_A2 PM2_25a_A3 PM2_25a_E1 PM2_25a_E2 PM2_25a_E3 ///
PM3_25a_A1 PM3_25a_A2 PM3_25a_A3 PM3_25a_E1 PM3_25a_E2 PM3_25a_E3 ///
PM4_25a_A1 PM4_25a_A2 PM4_25a_A3 PM4_25a_E1 PM4_25a_E2 PM4_25a_E3 ///
PM5_25a_A1 PM5_25a_A2 PM5_25a_A3 PM5_25a_E1 PM5_25a_E2 PM5_25a_E3{
recode `x'p (4 = 0.5) (3 = 1) (2 = 0.66) (1 = 0.33) (0 = 0.33) (99 = .) (98 = 0.33)
}

**Third, recode MS decision making, from 98 into zero. This makes a basic distinction between collective state bodies deciding by consensus, and individual MS decisions. The former constitute a weak form of pooling; the latter constitute zero pooling. 

foreach x of varlist ACC16a_MS SUSP18a_MS CON19a_MS BUD22a_MS COM24a_MS PM1_25a_MS PM2_25a_MS PM3_25a_MS ///
PM4_25a_MS PM5_25a_MS{
recode `x'p (98 = 0) (99 = .) 
}

**Now include technocratic decision making*
recode ACC16a_technocratic (1 = 0.5) 
recode SUSP18a_technocratic (1 = 0.5)
recode COM24a_technocratic (1 = 0.5)

*STEP 3: Aggregate by decision area: for each body and decision-making area, select the AVERAGE value*
*accession*
egen ACCa_pool = rowmean(ACC16a_A1p ACC16a_A2p ACC16a_A3p ACC16a_E1p ACC16a_E2p ACC16a_E3p ACC16a_MSp ACC16a_technocratic ACC16a_MSp)

*suspension*
egen SUSPa_pool = rowmean(SUSP18a_A1p SUSP18a_A2p SUSP18a_A3p SUSP18a_E1p SUSP18a_E2p SUSP18a_E3p SUSP18a_MSp SUSP18a_technocratic SUSP18a_MSp)

*constitutional amendments*
egen CONa_pool = rowmean(CON19a_A1p CON19a_A2p CON19a_A3p CON19a_E1p CON19a_E2p CON19a_E3p CON19a_MSp CON19a_MSp)

*budgetary allocation*
egen BUDa_pool = rowmean(BUD22a_A1p BUD22a_A2p BUD22a_A3p BUD22a_E1p BUD22a_E2p BUD22a_E3p BUD22a_MSp)

*budgetary non-compliance*
egen COMa_pool = rowmean(COM24a_A1p COM24a_A2p COM24a_A3p COM24a_E1p COM24a_E2p COM24a_E3p COM24a_MSp COM24a_technocratic COM24a_MSp)

*policy-making*
egen PM1ap = rowmean(PM1_25a_A1p PM1_25a_A2p PM1_25a_A3p ///
PM1_25a_E1p PM1_25a_E2p PM1_25a_E3p PM1_25a_MSp)
egen PM2ap = rowmean(PM2_25a_A1p PM2_25a_A2p PM2_25a_A3p ///
PM2_25a_E1p PM2_25a_E2p PM2_25a_E3p PM2_25a_MSp)
egen PM3ap = rowmean(PM3_25a_A1p PM3_25a_A2p PM3_25a_A3p ///
PM3_25a_E1p PM3_25a_E2p PM3_25a_E3p PM3_25a_MSp)
egen PM4ap = rowmean(PM4_25a_A1p PM4_25a_A2p PM4_25a_A3p ///
PM4_25a_E1p PM4_25a_E2p PM4_25a_E3p PM4_25a_MSp)
egen PM5ap = rowmean(PM5_25a_A1p PM5_25a_A2p PM5_25a_A3p ///
PM5_25a_E1p PM5_25a_E2p PM5_25a_E3p PM5_25a_MSp)
egen POLa_pool = rowmean(PM1ap PM2ap PM3ap PM4ap PM5ap)

*account for no rules/ not applicable; descriptives
replace ACCa_pool=. if ACC16a_norule==99
replace SUSPa_pool=. if SUSP18a_norule==1| SUSP18a_norule==99
replace CONa_pool=. if CON19a_norule==99
replace BUDa_pool=. if BUD22a_norule==99| BUD22a_norule==98
replace COMa_pool=. if COM24a_norule==99|COM24a_norule==98
replace COMa_pool=. if (COM24a_norule==98 & ionumber==1830 & year<1958)| (COM24a_norule==98 & ionumber==1830 & year>1970)
replace POLa_pool=. if PM1_25a_norule==99 & POLa_pool==.

tab ACCa_pool
tab SUSPa_pool
tab CONa_pool
tab BUDa_pool
tab COMa_pool
tab POLa_pool

pwcorr ACCa_pool SUSPa_pool CONa_pool BUDa_pool COMa_pool POLa_pool

**HOLD ON!! These are NOT the agenda setting scores in pooling yet--we need to incorporate bindingness and ratification!!!

*************************************************
**POOLING IN FINAL DECISION** 
*The logic is quite different from agenda setting, which is inclusive. The logic of pooling in decision making is to identify the lowest common denominator: the most intergovernmental decision body.

***************************************

*STEP 1: generate pooling variables: determine which bodies are involved in final decision-making*
foreach x of varlist ACC16b_A1 ACC16b_A2 ACC16b_A3 ACC16b_E1 ACC16b_E2 ACC16b_E3 ///
SUSP18b_A1 SUSP18b_A2 SUSP18b_A3 SUSP18b_E1 SUSP18b_E2 SUSP18b_E3 ///
CON19b_A1 CON19b_A2 CON19b_A3 CON19b_E1 CON19b_E2 CON19b_E3 ///
BUD22b_A1 BUD22b_A2 BUD22b_A3 BUD22b_E1 BUD22b_E2 BUD22b_E3 ///
COM24b_A1 COM24b_A2 COM24b_A3 COM24b_E1 COM24b_E2 COM24b_E3 ///
PM1_25b_A1 PM1_25b_A2 PM1_25b_A3 PM1_25b_E1 PM1_25b_E2 PM1_25b_E3 ///
PM2_25b_A1 PM2_25b_A2 PM2_25b_A3 PM2_25b_E1 PM2_25b_E2 PM2_25b_E3 ///
PM3_25b_A1 PM3_25b_A2 PM3_25b_A3 PM3_25b_E1 PM3_25b_E2 PM3_25b_E3 ///
PM4_25b_A1 PM4_25b_A2 PM4_25b_A3 PM4_25b_E1 PM4_25b_E2 PM4_25b_E3 ///
PM5_25b_A1 PM5_25b_A2 PM5_25b_A3 PM5_25b_E1 PM5_25b_E2 PM5_25b_E3{
gen `x'p = .
}

*STEP 2: VOTING RULE: Let pooling variables take on the values of originals if body is MS dominated*
foreach x of varlist ACC16b_A1 SUSP18b_A1 CON19b_A1 BUD22b_A1 COM24b_A1 ///
PM1_25b_A1 PM2_25b_A1 PM3_25b_A1 PM4_25b_A1 PM5_25b_A1{
replace `x'p = `x' if A1_ms==1            
}

foreach x of varlist ACC16b_A2 SUSP18b_A2 CON19b_A2 BUD22b_A2 COM24b_A2 ///
PM1_25b_A2 PM2_25b_A2 PM3_25b_A2 PM4_25b_A2 PM5_25b_A2{
replace `x'p = `x' if A2_ms==1            
}

foreach x of varlist ACC16b_A3 SUSP18b_A3 CON19b_A3 BUD22b_A3 COM24b_A3 ///
PM1_25b_A3 PM2_25b_A3 PM3_25b_A3 PM4_25b_A3 PM5_25b_A3{
replace `x'p = `x' if A3_ms==1            
}

foreach x of varlist ACC16b_E1 SUSP18b_E1 CON19b_E1 BUD22b_E1 COM24b_E1 ///
PM1_25b_E1 PM2_25b_E1 PM3_25b_E1 PM4_25b_E1 PM5_25b_E1{
replace `x'p = `x' if E1_ms==1            
}

foreach x of varlist ACC16b_E2 SUSP18b_E2 CON19b_E2 BUD22b_E2 COM24b_E2 ///
PM1_25b_E2 PM2_25b_E2 PM3_25b_E2 PM4_25b_E2 PM5_25b_E2{
replace `x'p = `x' if E2_ms==1            
}

foreach x of varlist ACC16b_E3 SUSP18b_E3 CON19b_E3 BUD22b_E3 COM24b_E3 ///
PM1_25b_E3 PM2_25b_E3 PM3_25b_E3 PM4_25b_E3 PM5_25b_E3{
replace `x'p = `x' if E3_ms==1            
}
  
*STEP 3: Refine decision-making coding on pooling variables -- final decision*
*first, take into account weighted voting* 
* and next, recode decision rules*
foreach x of varlist ACC16b_A1 SUSP18b_A1 CON19b_A1 BUD22b_A1 COM24b_A1 PM1_25b_A1 PM2_25b_A1 PM3_25b_A1 PM4_25b_A1 PM5_25b_A1{
recode `x'p (3 = 2) if A1_3a==1
}

foreach x of varlist ACC16b_E1 SUSP18b_E1 CON19b_E1 BUD22b_E1 COM24b_E1 PM1_25b_E1 PM2_25b_E1 PM3_25b_E1 PM4_25b_E1 PM5_25b_E1{
recode `x'p (3 = 2) if E1_9b==1
}

foreach x of varlist ACC16b_E2 SUSP18b_E2 CON19b_E2 BUD22b_E2 COM24b_E2 PM1_25b_E2 PM2_25b_E2 PM3_25b_E2 PM4_25b_E2 PM5_25b_E2{
recode `x'p (3 = 2) if E2_9b==1
}

foreach x of varlist ACC16b_E3 SUSP18b_E3 CON19b_E3 BUD22b_E3 COM24b_E3 PM1_25b_E3 PM2_25b_E3 PM3_25b_E3 PM4_25b_E3 PM5_25b_E3{
recode `x'p (3 = 2) if E3_9b==1
}
foreach x of varlist ACC16b_A1 ACC16b_A2 ACC16b_A3 ACC16b_E1 ACC16b_E2 ACC16b_E3 ///
SUSP18b_A1 SUSP18b_A2 SUSP18b_A3 SUSP18b_E1 SUSP18b_E2 SUSP18b_E3 ///
CON19b_A1 CON19b_A2 CON19b_A3 CON19b_E1 CON19b_E2 CON19b_E3 ///
BUD22b_A1 BUD22b_A2 BUD22b_A3 BUD22b_E1 BUD22b_E2 BUD22b_E3 ///
COM24b_A1 COM24b_A2 COM24b_A3 COM24b_E1 COM24b_E2 COM24b_E3 ///
PM1_25b_A1 PM1_25b_A2 PM1_25b_A3 PM1_25b_E1 PM1_25b_E2 PM1_25b_E3 ///
PM2_25b_A1 PM2_25b_A2 PM2_25b_A3 PM2_25b_E1 PM2_25b_E2 PM2_25b_E3 ///
PM3_25b_A1 PM3_25b_A2 PM3_25b_A3 PM3_25b_E1 PM3_25b_E2 PM3_25b_E3 ///
PM4_25b_A1 PM4_25b_A2 PM4_25b_A3 PM4_25b_E1 PM4_25b_E2 PM4_25b_E3 ///
PM5_25b_A1 PM5_25b_A2 PM5_25b_A3 PM5_25b_E1 PM5_25b_E2 PM5_25b_E3{
recode `x'p (4 = 0.5) (3 = 1) (2 = 0.66) (1 = 0.33) (0 = 0.33)(99 = .) (98 = 0)
}

* for MS decision making, recode 98 into zero
gen ACC16b_MSp=0 if (ACC16b_MS==98| ACC16b_MS==99)
gen SUSP18b_MSp=0 if (SUSP18b_MS==98| SUSP18b_MS==99)
gen CON19b_MSp=0 if (CON19b_MS==98| CON19b_MS==99)
gen BUD22b_MSp=0 if (BUD22b_MS==98| BUD22b_MS==99)
gen COM24b_MSp=0 if (COM24b_MS==98| COM24b_MS==99)
gen PM1_25b_MSp=0 if (PM1_25b_MS==98| PM1_25b_MS==99)
gen PM2_25b_MSp=0 if (PM2_25b_MS==98| PM2_25b_MS==99)
gen PM3_25b_MSp=0 if (PM3_25b_MS==98| PM3_25b_MS==99)
gen PM4_25b_MSp=0 if (PM4_25b_MS==98| PM4_25b_MS==99)
gen PM5_25b_MSp=0 if (PM5_25b_MS==98| PM5_25b_MS==99)

*now include variables that indicate technocratic decision making*
recode ACC16b_technocratic (1 = 0.5) 
recode SUSP18b_technocratic (1 = 0.5) 
recode COM24b_technocratic (1 = 0.5) 

*STEP 4: AGGREGATE. For each body and decision-making area, select the lowest value; for policy making, select average of five streams*
*accession*
egen ACCb_pool = rowmin(ACC16b_A1p ACC16b_A2p ACC16b_A3p ACC16b_E1p ACC16b_E2p ACC16b_E3p ACC16b_MSp ACC16b_technocratic ACC16b_MSp)

*suspension*
egen SUSPb_pool = rowmin(SUSP18b_A1p SUSP18b_A2p SUSP18b_A3p SUSP18b_E1p SUSP18b_E2p SUSP18b_E3p SUSP18b_MSp SUSP18b_technocratic SUSP18b_MSp)

*constitutional amendments*
egen CONb_pool = rowmin(CON19b_A1p CON19b_A2p CON19b_A3p CON19b_E1p CON19b_E2p CON19b_E3p CON19b_MSp)

*budgetary allocation*
egen BUDb_pool = rowmin(BUD22b_A1p BUD22b_A2p BUD22b_A3p BUD22b_E1p BUD22b_E2p BUD22b_E3p BUD22b_MSp)

*budgetary non-compliance*
egen COMb_pool = rowmin(COM24b_A1p COM24b_A2p COM24b_A3p COM24b_E1p COM24b_E2p COM24b_E3p COM24b_MSp COM24b_technocratic COM24b_MSp)

*policy-making*
egen PM1bp = rowmin(PM1_25b_A1p PM1_25b_A2p PM1_25b_A3p ///
PM1_25b_E1p PM1_25b_E2p PM1_25b_E3p PM1_25b_MSp)
egen PM2bp = rowmin(PM2_25b_A1p PM2_25b_A2p PM2_25b_A3p ///
PM2_25b_E1p PM2_25b_E2p PM2_25b_E3p PM2_25b_MSp)
egen PM3bp = rowmin(PM3_25b_A1p PM3_25b_A2p PM3_25b_A3p ///
PM3_25b_E1p PM3_25b_E2p PM3_25b_E3p PM3_25b_MSp)
egen PM4bp = rowmin(PM4_25b_A1p PM4_25b_A2p PM4_25b_A3p ///
PM4_25b_E1p PM4_25b_E2p PM4_25b_E3p PM4_25b_MSp)
egen PM5bp = rowmin(PM5_25b_A1p PM5_25b_A2p PM5_25b_A3p ///
PM5_25b_E1p PM5_25b_E2p PM5_25b_E3p PM5_25b_MSp)
egen POLb_pool = rowmean(PM1bp PM2bp PM3bp PM4bp PM5bp)

*account for no rules/ not applicable
replace ACCb_pool=. if ACC16b_norule==99
replace SUSPb_pool=. if SUSP18b_norule==1| SUSP18a_norule==99
replace CONb_pool=. if CON19b_norule==99
replace BUDb_pool=. if BUD22b_norule==99| BUD22b_norule==98
replace COMb_pool=. if COM24b_norule==99|COM24b_norule==98
replace COMb_pool=. if (COM24b_norule==98 & ionumber==1830 & year<1958)| (COM24b_norule==98 & ionumber==1830 & year>1970)
replace POLb_pool=. if PM1_25b_norule==99 & POLb_pool==.

tab ACCb_pool
tab SUSPb_pool
tab CONb_pool
tab BUDb_pool
tab COMb_pool
tab POLb_pool

pwcorr ACCb_pool SUSPb_pool CONb_pool BUDb_pool COMb_pool POLb_pool

**HOLD ON!! These are NOT the final decision scores in pooling yet--we need to incorporate bindingness and ratification!!!

*************************************************
*POOLING IN AGENDA SETTING AND DELEGATION -- AGGREGATE
**********************************************************
*STEP 1: Weigh variables for bindingness and ratification (except policy)*
  *recode variables for bindingness and ratification*
recode ACC17 (2 = 1) (1 = 0.75) (0 = 0.25) (98 = 1) (99 = .)
recode CON20 (3 = 1) (2 = 0.75) (1 = 0.5) (0 = 0.25) (98 = 1) (99 = .)
recode BUD23 (2 = 1) (1 = 0.75) (0 = 0.25) (98 = 1) (99 = .)

gen ACCaw_pool = ACCa_pool * ACC17
gen SUSPaw_pool = SUSPa_pool
gen CONaw_pool = CONa_pool * CON20
gen BUDaw_pool = BUDa_pool * BUD23
gen COMaw_pool= COMa_pool
gen ACCbw_pool = ACCb_pool * ACC17
gen SUSPbw_pool = SUSPb_pool
gen CONbw_pool = CONb_pool * CON20
gen BUDbw_pool = BUDb_pool * BUD23
gen COMbw_pool= COMb_pool

*STEP 2: policy-making: 
* Calculate weight of bindingness and ratification*
recode PM1_26 (2 = 1) (1 = 0.75) (0 = 0.25) (98=1) (99=.)
recode PM2_26 (2 = 1) (1 = 0.75) (0 = 0.25) (98=1) (99=.)
recode PM3_26 (2 = 1) (1 = 0.75) (0 = 0.25) (98=1) (99=.)
recode PM4_26 (2 = 1) (1 = 0.75) (0 = 0.25) (98=1) (99=.)
recode PM5_26 (2 = 1) (1 = 0.75) (0 = 0.25) (98=1) (99=.)

recode PM1_27 (3=1) (2=0.75) (1=0.5) (0=0.25) (98=1) (99=.)
recode PM2_27 (3=1) (2=0.75) (1=0.5) (0=0.25) (98=1) (99=.)
recode PM3_27 (3=1) (2=0.75) (1=0.5) (0=0.25) (98=1) (99=.)
recode PM4_27 (3=1) (2=0.75) (1=0.5) (0=0.25) (98=1) (99=.)
recode PM5_27 (3=1) (2=0.75) (1=0.5) (0=0.25) (98=1) (99=.)

*Apply weights on agenda setting + final decision of policy
egen PM1aw_pool = rowmean(PM1_25a_A1p PM1_25a_A2p PM1_25a_A3p PM1_25a_E1p PM1_25a_E2p PM1_25a_E3p PM1_25a_MSp)
replace PM1aw_pool = PM1aw_pool*(PM1_26 * PM1_27)
egen PM2aw_pool = rowmean(PM2_25a_A1p PM2_25a_A2p PM2_25a_A3p PM2_25a_E1p PM2_25a_E2p PM2_25a_E3p PM2_25a_MSp)
replace PM2aw_pool = PM2aw_pool*(PM2_26 * PM2_27)
egen PM3aw_pool = rowmean(PM3_25a_A1p PM3_25a_A2p PM3_25a_A3p PM3_25a_E1p PM3_25a_E2p PM3_25a_E3p PM3_25a_MSp) 
replace PM3aw_pool = PM3aw_pool*(PM3_26 * PM3_27)
egen PM4aw_pool = rowmean(PM4_25a_A1p PM4_25a_A2p PM4_25a_A3p PM4_25a_E1p PM4_25a_E2p PM4_25a_E3p PM4_25a_MSp)
replace PM4aw_pool = PM4aw_pool * (PM4_26 * PM4_27)
egen PM5aw_pool = rowmean(PM5_25a_A1p PM5_25a_A2p PM5_25a_A3p PM5_25a_E1p PM5_25a_E2p PM5_25a_E3p PM5_25a_MSp)
replace PM5aw_pool = PM5aw_pool * (PM5_26 * PM5_27)
egen PMaw_pool = rowmean(PM1aw_pool PM2aw_pool PM3aw_pool PM4aw_pool PM5aw_pool)


egen PM1bw_pool = rowmin(PM1_25b_A1p PM1_25b_A2p PM1_25b_A3p PM1_25b_E1p PM1_25b_E2p PM1_25b_E3p PM1_25b_MSp)
replace PM1bw_pool = PM1bw_pool*(PM1_26 * PM1_27)
egen PM2bw_pool = rowmin(PM2_25b_A1p PM2_25b_A2p PM2_25b_A3p PM2_25b_E1p PM2_25b_E2p PM2_25b_E3p PM1_25b_MSp)
replace PM2bw_pool = PM2bw_pool*(PM2_26 * PM2_27)
egen PM3bw_pool = rowmin(PM3_25b_A1p PM3_25b_A2p PM3_25b_A3p PM3_25b_E1p PM3_25b_E2p PM3_25b_E3p PM1_25b_MSp)
replace PM3bw_pool = PM3aw_pool*(PM3_26 * PM3_27)
egen PM4bw_pool = rowmin(PM4_25b_A1p PM4_25b_A2p PM4_25b_A3p PM4_25b_E1p PM4_25b_E2p PM4_25b_E3p PM1_25b_MSp)
replace PM4bw_pool = PM4bw_pool * (PM4_26 * PM4_27)
egen PM5bw_pool = rowmin(PM5_25b_A1p PM5_25b_A2p PM5_25b_A3p PM5_25b_E1p PM5_25b_E2p PM5_25b_E3p PM1_25b_MSp)
replace PM5bw_pool = PM5bw_pool * (PM5_26 * PM5_27)
egen PMbw_pool = rowmean(PM1bw_pool PM2bw_pool PM3bw_pool PM4bw_pool PM5bw_pool)


*STEP 3: now set missing values equivalent to zero on pooling
replace ACCaw_pool=0 if ACCaw_pool==.
replace ACCaw_pool=0 if ACCaw_pool==.
replace SUSPaw_pool=0 if  SUSPaw_pool==.
replace CONaw_pool = 0 if CONaw_pool==.
replace BUDaw_pool = 0 if BUDaw_pool==. 
replace COMaw_pool= 0 if COMaw_pool==.
replace PMaw_pool=0 if PMaw_pool==.
replace ACCbw_pool = 0 if ACCbw_pool==.
replace SUSPbw_pool = 0 if SUSPbw_pool==.
replace CONbw_pool = 0 if CONbw_pool==.
replace BUDbw_pool = 0 if BUDbw_pool==.
replace COMbw_pool=0 if COMbw_pool==.
replace PMbw_pool=0 if PMbw_pool==.

*STEP 4: AGGREGATION

*By decision stage, descriptives
gen poolagenda=(ACCaw_pool + SUSPaw_pool + CONaw_pool + BUDaw_pool + COMaw_pool + PMaw_pool)/6
gen poolfinal=(ACCbw_pool + SUSPbw_pool + CONbw_pool + BUDbw_pool + COMbw_pool + PMbw_pool)/6

tab poolagenda
tab poolfinal
corr poolagenda poolfinal

*By decision area, descriptives
*sum each decision area separately: sum agenda-setting and final decision making 

gen poolaccess = (ACCaw_pool + ACCbw_pool)/2
gen poolsuspens = (SUSPaw_pool + SUSPbw_pool)/2
gen poolconstit = (CONaw_pool + CONbw_pool)/2
gen poolbudget = (BUDaw_pool + BUDbw_pool)/2
gen poolcompliance = (COMaw_pool + COMbw_pool)/2
gen poolpolicy = (PMaw_pool + PMbw_pool)/2

tab poolaccess
tab poolsuspens
tab poolconstit
tab poolbudget
tab poolcompliance
tab poolpolicy

corr poolaccess poolsuspens poolconstit poolbudget poolpolicy

gen pooling2= (poolagenda + poolfinal)/2
gen pooling6= (poolaccess + poolsuspens + poolconstit + poolbudget + poolcompliance + poolpolicy)/6
corr pooling2 pooling6
tabstat pooling2 pooling6, stats (min max p25 p75 mean N)
gen pooling12 = (ACCaw_pool + SUSPaw_pool + CONaw_pool + BUDaw_pool + COMaw_pool + PMaw_pool +ACCbw_pool + SUSPbw_pool + CONbw_pool + BUDbw_pool + COMbw_pool + PMbw_pool)/12
*ROBUSTNESS CHECK: pooling2, pooling6, pooling12 should be identical


*now add labels for key variables*
label var ACC17 "weight for accession"
label var CON20 "weight for constitutional"
label var BUD23 "weight for budgetary allocation"
label var poolagenda "pooling agenda setting, 0-1"
label var poolfinal "pooling final decision, 0-1"
label var pooling2 "pooling, agenda & final,0-1)"
label var pooling6 "pooling, 6 decision areas,0-1)"
label var poolaccess "accession pooling (weighted, 0-1)"
label var poolconstit "constitutional pooling (weighted, 0-1)"
label var poolsuspens "suspension pooling (0-1)"
label var poolcompliance "financial compliance pooling (0-1)"
label var poolbudget "budgetary allocation pooling (weighted, 0-1)"
label var poolpolicy "policy making pooling (weighted, 0-1)"

order ioname acronym ionumber year inception initial end typeI ///
delegation6 delegation3 delaccess delsuspens delconstit delbudget delfincompl delpolicy del_agenda del_final DS_sum_st ///
pooling2 pooling6 poolaccess poolconstit poolsuspens poolbudget poolcompliance poolpolicy poolagenda poolfinal, after (typeI)

************************************************
**or for clean dataset
************************************************ 
keep ioname acronym ionumber year inception initial end typeI ///
delegation6 delaccess delsuspens delconstit delbudget delfincompl delpolicy del_agenda del_final DS_sum_st ///
pooling6 poolaccess poolsuspens poolconstit poolbudget poolcompliance  poolpolicy poolagenda poolfinal
rename delegation6 delegation
rename pooling6 pooling
label var delegation "aggregate delegation score"
label var pooling "aggregate pooling score"
order delegation, after (del_final)
order poolagenda poolfinal pooling, after (poolpolicy)


************************************************
**to create tables on delegation and pooling (Appendix III)
************************************************

///DROPPING DUPLICATE OBSERVATIONS IN ORDER TO CREATE FINAL TABLES 
**MIA tables for delegation
preserve
by ionumber (year), sort : gen delegation_diff=1 if delegation[_n-1]!=delegation[_n]
drop if delegation_diff !=1
sort ioname year
br ioname inception year delaccess delsuspens delconstit delbudget delfincompl delpolicy ///
 DS_sum_st delegation

*generate MIA tables automatically
tostring year, generate (years) 
by ionumber (year), sort: gen years1=year[_n+1]
by ionumber (year), sort: gen   years2=years1-1
tostring years2, generate (years22)
replace years22="2010" if years22=="."


gen str8 dash ="-"
by ionumber (year), sort: gen  str10 years3=years+dash+years22
replace years3=years if years22==years
replace years3="1974-1991" if ioname=="COMECON"&years3=="1974-2010" 
replace years3="1974-1976" if ioname=="EAC1"&years3=="1974-2010" 

gen ioname1=ioname
replace ioname1="" if ioname[_n-1]==ioname

sort ioname year
br ioname1  years3 delaccess delsuspens delconstit delbudget delfincompl delpolicy ///
 del_agenda  del_final DS_sum_st delegation



**MIA tables for pooling
restore
by ionumber (year), sort : gen pooling_diff=1 if pooling[_n-1]!=pooling[_n]
drop if pooling_diff !=1
sort ioname year

*generate MIA tables automatically
tostring year, generate (years) 
by ionumber (year), sort: gen years1=year[_n+1]
by ionumber (year), sort: gen   years2=years1-1
tostring years2, generate (years22)
replace years22="2010" if years22=="." 

gen str8 dash ="-"
by ionumber (year), sort: gen  str10 years3=years+dash+years22
replace years3=years if years22==years
replace years3="1959-1991" if ioname=="COMECON"&years3=="1959-2010" 
replace years3="1967-1976" if ioname=="EAC1"&years3=="1967-2010" 

gen ioname1=ioname
replace ioname1="" if ioname[_n-1]==ioname

sort ioname year
br ioname1  years3 poolaccess poolsuspens poolconstit poolbudget poolcompliance poolpolicy poolagenda poolfinal pooling


